@@ -9,6 +9,9 @@ BUGSmodel <- function(code, name, constants=list(), dimensions=list(), data=list
       stop("BUGSmodel: 'dimensions' must be a named list")
     if(length(data) && sum(names(data) == ""))
         stop("BUGSmodel: 'data' must be a named list")
+    if(any(!sapply(data, function(x) {
+        is.numeric(x) || is.logical(x) })))
+        stop("BUGSmodel: elements of 'data' must be numeric and cannot be data frames")
     ## constantLengths <- unlist(lapply(constants, length))
     ## if(any(constantLengths > 1)) {
     ##     iLong <- which(constantLengths > 1)
