@@ -15,7 +15,7 @@
 #'
 #' \code{niter}: The number of iterations to run the MCMC.
 #'
-#' \code{reset}: Boolean specifying whether to reset the model and stored samples.  This will simulate into any stochastic nodes with value NA, propagate values through any deterministic nodes, and calculate all model probabilities. This will also reset the internal stored MCMC samples. Specifying \code{reset=FALSE} allows the MCMC algorithm to continue running from where it left off. Generally, \code{reset=FALSE} should only be used when the MCMC has already been run (default = TRUE).
+#' \code{reset}: Boolean specifying whether to reset the internal MCMC sampling algorithms to their initial state (in terms of self-adapting tuning parameters), and begin recording posterior sample chains anew. Specifying \code{reset=FALSE} allows the MCMC algorithm to continue running from where it left off, appending additional posterior samples to the already existing sample chains. Generally, \code{reset=FALSE} should only be used when the MCMC has already been run (default = TRUE).
 #'
 #' \code{simulateAll}: Boolean specifying whether to simulate into all stochastic nodes.  This will overwrite the current values in all stochastic nodes (default = FALSE).
 #'
@@ -85,14 +85,14 @@ buildMCMC <- nimbleFunction(
             mvSamples2_offset <- 0
             resize(mvSamples,  niter/thin)
             resize(mvSamples2, niter/thin2)
-            samplerTimes <<- numeric(length(samplerFunctions))       ## default inititialization to zero
+            samplerTimes <<- numeric(length(samplerFunctions) + 1)       ## default inititialization to zero
         } else {
             mvSamples_offset  <- getsize(mvSamples)
             mvSamples2_offset <- getsize(mvSamples2)
             resize(mvSamples,  mvSamples_offset  + niter/thin)
             resize(mvSamples2, mvSamples2_offset + niter/thin2)
-            if(dim(samplerTimes)[1] != length(samplerFunctions))
-                samplerTimes <<- numeric(length(samplerFunctions))   ## first run: default inititialization to zero
+            if(dim(samplerTimes)[1] != length(samplerFunctions) + 1)
+                samplerTimes <<- numeric(length(samplerFunctions) + 1)   ## first run: default inititialization to zero
         }
         if(niter < progressBarLength+3) progressBar <- progressBar & 0  ## cheap way to avoid compiler warning
         if(progressBar) { for(iPB1 in 1:4) { cat('|'); for(iPB2 in 1:(progressBarLength/4)) cat('-') }; print('|'); cat('|') }
@@ -120,7 +120,7 @@ buildMCMC <- nimbleFunction(
     methods = list(
         getTimes = function() {
             returnType(double(1))
-            return(samplerTimes)
+            return(samplerTimes[1:(length(samplerTimes)-1)])
         }),
     where = getLoadingNamespace()
 )
