@@ -1,3 +1,6 @@
+# for use in DSL code check:
+otherDSLcalls <- c("{", "[[", "$", "resize", "declare", "returnType", "seq_along", "double", "rankSample")
+
 nimKeyWords <- list(copy = 'nimCopy',
                     print = 'nimPrint',
                     cat = 'nimCat',
@@ -23,13 +26,15 @@ nfMethodRC <-
                     neededRCfuns = 'ANY'		#list
                 ),
                 methods = list(
-                    initialize = function(method, name) {
+                    initialize = function(method, name, check = FALSE) {
                     	
                         if(!missing(name)) uniqueName <<- name ## only needed for a pure RC function. Not needed for a nimbleFunction method
                         neededRCfuns <<- list()	
                         argInfo <<- formals(method)
                         code <<- nf_changeNimKeywords(body(method))  ## changes all nimble keywords, e.g. 'print' to 'nimPrint'; see 'nimKeyWords' list at bottom
                         if(code[[1]] != '{')  code <<- substitute({CODE}, list(CODE=code))
+                        if(check && "package:nimble" %in% search()) # don't check nimble package nimbleFunctions
+                            nf_checkDSLcode(code)
                         generateArgs()
                         generateTemplate() ## used for argument matching
                         removeAndSetReturnType()
@@ -84,6 +89,39 @@ nfMethodRC <-
     )
 
 
+
+nf_checkDSLcode <- function(code) {  
+    dslCalls <- c(names(sizeCalls), otherDSLcalls, names(specificCallReplacements), nimKeyWords)
+    calls <- setdiff(all.names(code), all.vars(code))
+    # find cases of x$y() and x[]$y and x[[]]$y (this also unnecessarily finds x$y)
+    names <- all.names(code)
+    dollars <- which(names == "$")
+    if(length(dollars)) {
+        lhs <- dollars+1
+        while(sum(names[lhs] %in% c('[', '[[')))
+            lhs[names[lhs] %in% c('[', '[[')] <- lhs[names[lhs] %in% c('[', '[[')] + 1
+        lhs <- lhs[lhs <= length(names)]
+        otherVars <- unique(names[lhs])
+    } else otherVars <- NULL
+    
+    nonDSLcalls <- calls[!(calls %in% c(dslCalls, otherVars))]
+    if(length(nonDSLcalls)) {
+        objInR <- sapply(nonDSLcalls, exists)
+        nonDSLnonR <- nonDSLcalls[!objInR]
+        nonDSLinR <- nonDSLcalls[objInR]
+        if(length(nonDSLinR)) {
+            # problem with passing inputIsName when run through roxygen...
+            nonDSLinR <- nonDSLinR[!(sapply(nonDSLinR, function(x) is.nf(x, inputIsName = TRUE)) |
+                                     sapply(nonDSLinR, function(x) is.rcf(x, inputIsName = TRUE)))]
+            warning(paste0("Detected possible use of R functions in nimbleFunction run code. For this nimbleFunction to compile, these functions must defined as nimbleFunctions or nimbleFunction methods: ", paste(nonDSLinR, collapse = ', '), "."))
+            if("c" %in% nonDSLinR) warning("Note that until version 0.6-3 of NIMBLE, c() cannot be used as a stand-alone function, but its use to create vector arguments to a function may be valid.")
+        }
+        if(length(nonDSLnonR))
+            warning(paste0("For this nimbleFunction to compile, these functions must be defined as nimbleFunctions or nimbleFunction methods: ", paste(nonDSLnonR, collapse = ', '), "."))
+    }
+    return(0)
+}
+
 nf_changeNimKeywords <- function(code){
     if(length(code) > 0){
         for(i in seq_along(code) ) {
