@@ -187,6 +187,15 @@ cppNimbleFunctionClass <- setRefClass('cppNimbleFunctionClass',
                                                             SEXPgeneratorFun$name
                                                   Rgenerator <<- buildNimbleFxnInterface(paste0(name,'_refClass') , .self, sym, where = where)
                                               },
+                                              promoteCallable = function(R_NimbleFxn, asTopLevel = TRUE){
+                                                  ## see comment in nimbleProjectClass::compileNimbleFunction
+                                                  oldCobjectInterface <- nf_getRefClassObject(R_NimbleFxn)$.CobjectInterface
+                                                  if(!is.list(oldCobjectInterface)) return(oldCobjectInterface)
+                                                  existingBasePtr <- oldCobjectInterface[[1]]$getBasePtr(oldCobjectInterface[[2]])
+                                                  thisDll <- oldCobjectInterface[[1]]$dll
+                                                  newCobjectInterface <- Rgenerator(R_NimbleFxn, thisDll, project = nimbleProject, existingBasePtr = existingBasePtr)
+                                                  newCobjectInterface
+                                              },
                                               buildCallable = function(R_NimbleFxn, dll = NULL, asTopLevel = TRUE){
                                              ##     cat('buildCallable\n')
                                                   if(asTopLevel) {
