@@ -25,7 +25,7 @@ distributionsInputList <- list(
     dbin    = list(BUGSdist = 'dbin(prob, size)',
                    Rdist    = 'dbinom(size, prob)',
                    discrete = TRUE,
-                   range = c(0, Inf),
+                   range = c('lower = 0', 'upper = size'),
                    pqAvail = TRUE,
                    alias   = 'dbinom'),
     
@@ -108,18 +108,18 @@ distributionsInputList <- list(
     dnorm   = list(BUGSdist = 'dnorm(mean, tau, sd, var)',
                    Rdist    = c('dnorm(mean, sd = 1/sqrt(tau))', 'dnorm(mean, sd = sqrt(var))'),
                    altParams= c('tau = sd^-2', 'var = sd*sd'),
-#                   altParams= c('tau = sd^-2', 'var = sd^2'),
                    pqAvail = TRUE),
     
-    ## dpar    = list(BUGSdist = 'dpar(alpha, c)'),   ## not sure the state of this?  -DT
-    
     dt      = list(BUGSdist = 'dt(mu, tau, df, sigma, sigma2)',
                    Rdist    = c('dt_nonstandard(df, mu, sigma = 1/sqrt(tau))',
                        'dt_nonstandard(df, mu, sigma = sqrt(sigma2))'),
                    altParams = c('tau = sigma^-2', 'sigma2 = sigma^2'),
                    pqAvail = TRUE),
     
-    dunif   = list(BUGSdist = 'dunif(min, max)',
+    dunif   = list(BUGSdist = 'dunif(min, max, mean, sd)',
+                   Rdist    = c('dunif(min = mean - sqrt(3)*sd, max = mean + sqrt(3)*sd)'),
+                   altParams = c('mean = (min + max)/2', 'sd = (max - min)/sqrt(12)'),
+                   range = c('lower = min', 'upper = max'),
                    pqAvail = TRUE),
     
     dweib   = list(BUGSdist = 'dweib(shape, lambda, scale, rate)',
@@ -161,7 +161,6 @@ distributionsInputList <- list(
     
     dwish   = list(BUGSdist = 'dwish(R, df, S)',
                    Rdist    = c('dwish_chol(cholesky = chol(R), df, scale_param = 0)', 'dwish_chol(cholesky = chol(S), df, scale_param = 1)'),
-                  # altParams = c('R = cholesky', 'S = cholesky'), ##NOT CORRECT. These are placeholders to get other parts working.
                    altParams = c('R = inverse(t(cholesky)%*%cholesky)', 'S = inverse(t(cholesky)%*%cholesky)'),
                    alias    = 'dwishart',
                    types    = c('value = double(2)', 'R = double(2)', 'S = double(2)', 'cholesky = double(2)'))
