@@ -28,7 +28,7 @@ nimbleFunctionVirtual <- function(contains = NULL,
     className <- name
     ## We make this look like a nimbleFunction in relevants ways for compilation
     methodList <- c(list(run = run), methods)   # create a list of the run function, and all other methods
-    methodList <- lapply(methodList, nfMethodRC)
+    methodList <- lapply(methodList, nfMethodRC, check = FALSE)
 ##    CclassName <- as.character(NA) ##Rname2CppName(className)
     generatorFunction <- function() {}
     force(contains)
@@ -47,6 +47,7 @@ nimbleFunctionVirtual <- function(contains = NULL,
 #' @param globalSetup For internal use only
 #' @param contains An optional object returned from \link{nimbleFunctionVirtual} that defines arguments and returnTypes for \code{run} and/or methods, to which the current nimbleFunction must conform
 #' @param name An optional name used internally, for example in generated C++ code.  Usually this is left blank and NIMBLE provides a name.
+#' @param check Boolean indicating whether to check the run (DSL) code for function calls that NIMBLE cannot compile. Checking can be turned off for all calls to \code{nimbleFunction} using \code{nimbleOptions(checkNimbleFunction = FALSE)}.
 #' @param where An optional \code{where} argument passed to \code{setRefClass} for where the reference class definition generated for this nimbleFunction will be stored.  This is needed due to R package namespace issues but should never need to be provided by a user.
 #'
 #' @author NIMBLE development team
@@ -71,6 +72,7 @@ nimbleFunction <- function(setup         = NULL,
                            globalSetup   = NULL,
                            contains      = NULL,
                            name          = NA,
+                           check         = getNimbleOption('checkNimbleFunction'),
                            where         = getNimbleFunctionEnvironment()
                            ) {
 
@@ -79,7 +81,7 @@ nimbleFunction <- function(setup         = NULL,
     if(is.null(setup)) {
         if(length(methods) > 0) stop('Cannot provide multiple methods if there is no setup function.  Use "setup = function(){}" or "setup = TRUE" if you need a setup function that does not do anything', call. = FALSE)
         if(!is.null(contains)) stop('Cannot provide a contains argument if there is no setup function.  Use "setup = function(){}" or "setup = TRUE" if you need a setup function that does not do anything', call. = FALSE)
-        return(RCfunction(run, name = name))
+        return(RCfunction(run, name = name, check = check))
     }
    
     virtual <- FALSE
@@ -89,7 +91,7 @@ nimbleFunction <- function(setup         = NULL,
     className <- name
 
     methodList <- c(list(run = run), methods)   # create a list of the run function, and all other methods
-    methodList <- lapply(methodList, nfMethodRC)
+    methodList <- lapply(methodList, nfMethodRC, check = check)
     ## record any setupOutputs declared by setupOutput()
     setupOutputsDeclaration <- nf_processSetupFunctionBody(setup, returnSetupOutputDeclaration = TRUE)
     declaredSetupOutputNames <- nf_getNamesFromSetupOutputDeclaration(setupOutputsDeclaration)
